@@ -18,19 +18,12 @@ clear_f1_cache <- function() {
   if (reticulate::py_available(initialize = TRUE)) {
     if ("fastf1" %in% reticulate::py_list_packages()$package) {
       reticulate::py_run_string("import fastf1")
-      if (get_fastf1_version()$major >= 3) {
-        try(
-          reticulate::py_run_string(glue::glue("fastf1.Cache.clear_cache('{cache_dir}')",
-            cache_dir = normalizePath(getOption("f1dataR.cache"))
-          ))
-        )
-      } else {
-        try(
-          reticulate::py_run_string(glue::glue("fastf1.api.Cache.clear_cache('{cache_dir}')",
-            cache_dir = normalizePath(getOption("f1dataR.cache"))
-          ))
-        )
-      }
+
+      try(
+        reticulate::py_run_string(glue::glue("fastf1.Cache.clear_cache('{cache_dir}')",
+          cache_dir = normalizePath(getOption("f1dataR.cache"))
+        ))
+      )
     }
   }
 
